==> jc-1.4.0.tar.gz: soot/toolkits/scalar/AbstractBoundedFlowSet.h <==
// public abstract class soot.toolkits.scalar.AbstractBoundedFlowSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c6934e8762f5dae soot_toolkits_scalar_AbstractBoundedFlowSet
// @dep_class f9c213c375421b6c soot_toolkits_scalar_AbstractFlowSet

// header file dependencies
// @dep_header soot_toolkits_scalar_AbstractFlowSet

#include "soot/toolkits/scalar/AbstractFlowSet.h"

#ifndef _JC_soot_toolkits_scalar_AbstractBoundedFlowSet_H_
#define _JC_soot_toolkits_scalar_AbstractBoundedFlowSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_refs	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_refs;
typedef struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_nonrefs	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$refs	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$refs;
typedef struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$nonrefs	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$nonrefs;
typedef struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object;

typedef const struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vmethods	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vmethods;
typedef const struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtable	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtable;
typedef const struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtype	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *);

// Virtual methods
extern void _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method$complement$322b41c3e1df600c(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *);
extern void _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method$complement$c4d7bbf3d81bd19b(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method$topSet$e2d0352061e0f54e(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method_info$complement$322b41c3e1df600c;
extern _jc_method _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method_info$complement$c4d7bbf3d81bd19b;
extern _jc_method _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method_info$topSet$e2d0352061e0f54e;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vmethods {
	void	(*complement$322b41c3e1df600c)(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *);
	void	(*complement$c4d7bbf3d81bd19b)(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*topSet$e2d0352061e0f54e)(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowSet$vmethods	soot_toolkits_scalar_AbstractFlowSet;
	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vmethods	soot_toolkits_scalar_AbstractBoundedFlowSet;
};

// Vtype
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$refs {
    _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_refs	soot_toolkits_scalar_AbstractBoundedFlowSet;
    _jc_soot_toolkits_scalar_AbstractFlowSet$sub_refs	soot_toolkits_scalar_AbstractFlowSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowSet$sub_nonrefs	soot_toolkits_scalar_AbstractFlowSet;
    _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_nonrefs	soot_toolkits_scalar_AbstractBoundedFlowSet;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object {
	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtype	*vtype;
	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtype _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_AbstractBoundedFlowSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$class_object;

#endif	/* _JC_soot_toolkits_scalar_AbstractBoundedFlowSet_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/AbstractBoundedFlowSet.h <==
// public abstract class soot.toolkits.scalar.AbstractBoundedFlowSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6c6934e8762f5dae soot_toolkits_scalar_AbstractBoundedFlowSet
// @dep_class f9c213c375421b6c soot_toolkits_scalar_AbstractFlowSet

// header file dependencies
// @dep_header soot_toolkits_scalar_AbstractFlowSet

#include "soot/toolkits/scalar/AbstractFlowSet.h"

#ifndef _JC_soot_toolkits_scalar_AbstractBoundedFlowSet_H_
#define _JC_soot_toolkits_scalar_AbstractBoundedFlowSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_refs	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_refs;
typedef struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_nonrefs	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$refs	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$refs;
typedef struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$nonrefs	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$nonrefs;
typedef struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object;

typedef const struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vmethods	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vmethods;
typedef const struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtable	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtable;
typedef const struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtype	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method$complement$322b41c3e1df600c(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method$complement$c4d7bbf3d81bd19b(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method$topSet$e2d0352061e0f54e(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method_info$complement$322b41c3e1df600c;
extern _jc_method _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method_info$complement$c4d7bbf3d81bd19b;
extern _jc_method _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$method_info$topSet$e2d0352061e0f54e;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vmethods {
	void	(*complement$322b41c3e1df600c)(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *) _JC_JCNI_ATTR;
	void	(*complement$c4d7bbf3d81bd19b)(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*topSet$e2d0352061e0f54e)(_jc_env *, struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowSet$vmethods	soot_toolkits_scalar_AbstractFlowSet;
	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vmethods	soot_toolkits_scalar_AbstractBoundedFlowSet;
};

// Vtype
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$refs {
    _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_refs	soot_toolkits_scalar_AbstractBoundedFlowSet;
    _jc_soot_toolkits_scalar_AbstractFlowSet$sub_refs	soot_toolkits_scalar_AbstractFlowSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowSet$sub_nonrefs	soot_toolkits_scalar_AbstractFlowSet;
    _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$sub_nonrefs	soot_toolkits_scalar_AbstractBoundedFlowSet;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$object {
	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtype	*vtype;
	_jc_soot_toolkits_scalar_AbstractBoundedFlowSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$vtype _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_AbstractBoundedFlowSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_AbstractBoundedFlowSet$class_object;

#endif	/* _JC_soot_toolkits_scalar_AbstractBoundedFlowSet_H_ */
